import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class AccountFactoryService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all smart accounts
     * Get all the smart accounts for this account factory.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getAllAccounts(chain: string, contractAddress: string): CancelablePromise<{
        /**
         * The account addresses of all the accounts in this factory
         */
        result: Array<string>;
    }>;
    /**
     * Get associated smart accounts
     * Get all the smart accounts for this account factory associated with the specific admin wallet.
     * @param signerAddress The address of the signer to get associated accounts from
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getAssociatedAccounts(signerAddress: string, chain: string, contractAddress: string): CancelablePromise<{
        /**
         * The account addresses of all the accounts with a specific signer in this factory
         */
        result: Array<string>;
    }>;
    /**
     * Check if deployed
     * Check if a smart account has been deployed to the blockchain.
     * @param adminAddress The address of the admin to check if the account address is deployed
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param extraData Extra data to use in predicting the account address
     * @returns any Default Response
     * @throws ApiError
     */
    isAccountDeployed(adminAddress: string, chain: string, contractAddress: string, extraData?: string): CancelablePromise<{
        /**
         * Whether or not the account has been deployed
         */
        result: boolean;
    }>;
    /**
     * Predict smart account address
     * Get the counterfactual address of a smart account.
     * @param adminAddress The address of the admin to predict the account address for
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param extraData Extra data to add to use in predicting the account address
     * @returns any Default Response
     * @throws ApiError
     */
    predictAccountAddress(adminAddress: string, chain: string, contractAddress: string, extraData?: string): CancelablePromise<{
        /**
         * New account counter-factual address.
         */
        result: string;
    }>;
    /**
     * Create smart account
     * Create a smart account for this account factory.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    createAccount(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The admin address to create an account for
         */
        adminAddress: string;
        /**
         * Extra data to add to use in creating the account address
         */
        extraData?: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
}
