import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class BackendWalletService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create backend wallet
     * Create a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody?: {
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Import backend wallet
     * Import an existing wallet as a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    import(requestBody?: ({
        /**
         * AWS KMS key ID
         */
        awsKmsKeyId: string;
        /**
         * AWS KMS key ARN
         */
        awsKmsArn: string;
    } | {
        /**
         * GCP KMS key ID
         */
        gcpKmsKeyId: string;
        /**
         * GCP KMS key version ID
         */
        gcpKmsKeyVersionId: string;
    } | ({
        /**
         * The private key of the wallet to import
         */
        privateKey: string;
    } | {
        /**
         * The mnemonic phrase of the wallet to import
         */
        mnemonic: string;
    } | {
        /**
         * The encrypted JSON of the wallet to import
         */
        encryptedJson: string;
        /**
         * The password used to encrypt the encrypted JSON
         */
        password: string;
    }))): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Update backend wallet
     * Update a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    update(requestBody: {
        walletAddress: string;
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Get balance
     * Get the native balance for a backend wallet.
     * @param chain Chain name
     * @param walletAddress Backend wallet address
     * @returns any Default Response
     * @throws ApiError
     */
    getBalance(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            walletAddress: string;
            name: string;
            symbol: string;
            decimals: number;
            value: string;
            displayValue: string;
        };
    }>;
    /**
     * Get all backend wallets
     * Get all backend wallets.
     * @param page The page of wallets to get.
     * @param limit The number of wallets to get per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(page?: number, limit?: number): CancelablePromise<{
        result: Array<{
            /**
             * Wallet Address
             */
            address: string;
            /**
             * Wallet Type
             */
            type: string;
            label: (string | null);
            awsKmsKeyId: (string | null);
            awsKmsArn: (string | null);
            gcpKmsKeyId: (string | null);
            gcpKmsKeyRingId: (string | null);
            gcpKmsLocationId: (string | null);
            gcpKmsKeyVersionId: (string | null);
            gcpKmsResourcePath: (string | null);
        }>;
    }>;
    /**
     * Transfer tokens
     * Transfer native or ERC20 tokens from this wallet to another wallet
     * @param chain Chain name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to transfer to
         */
        to: string;
        /**
         * Address of the token to transfer
         */
        currencyAddress: string;
        /**
         * The amount of tokens to transfer
         */
        amount: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Withdraw all funds
     * Withdraw all funds from this wallet to another wallet
     * @param chain Chain name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    withdraw(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to withdraw all funds to
         */
        toAddress: string;
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a transaction
     * Send a transaction with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        toAddress?: string;
        data: string;
        value: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a batch of raw transactions
     * Send a batch of raw transactions with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransactionBatch(chain: string, xBackendWalletAddress: string, xAccountAddress?: string, xIdempotencyKey?: string, requestBody?: Array<{
        toAddress?: string;
        data: string;
        value: string;
    }>): CancelablePromise<{
        result: {
            groupId: string;
            queueIds: Array<string>;
        };
    }>;
    /**
     * Sign a transaction
     * Sign a transaction
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    signTransaction(xBackendWalletAddress: string, requestBody: {
        transaction: {
            to?: string;
            from?: string;
            nonce?: string;
            gasLimit?: string;
            gasPrice?: string;
            data?: string;
            value?: string;
            chainId?: number;
            type?: number;
            accessList?: any;
            maxFeePerGas?: string;
            maxPriorityFeePerGas?: string;
            customData?: Record<string, any>;
            ccipReadEnabled?: boolean;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Sign a message
     * Send a message
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    signMessage(xBackendWalletAddress: string, requestBody: {
        message: string;
        isBytes?: boolean;
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Sign an EIP-712 message
     * Send an EIP-712 message ("typed data")
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    signTypedData(xBackendWalletAddress: string, requestBody: {
        domain: Record<string, any>;
        types: Record<string, any>;
        value: Record<string, any>;
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Get all transactions
     * Get all transactions for a backend wallet.
     * @param chain Chain name
     * @param walletAddress Backend wallet address
     * @returns any Default Response
     * @throws ApiError
     */
    getAllTransactions(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                status: (string | null);
                /**
                 * The number of retry attempts
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
            }>;
        };
    }>;
    /**
     * Reset all nonces
     * Reset nonces for all backend wallets. This is for debugging purposes and does not impact held tokens.
     * @returns any Default Response
     * @throws ApiError
     */
    resetNonces(): CancelablePromise<{
        result: {
            status: string;
        };
    }>;
    /**
     * Get backend-wallet nonces from DB
     * Get nonce for a backend wallets from DB. This is for debugging purposes and does not impact held tokens.
     * @param chain Chain name
     * @param walletAddress Backend wallet address
     * @returns any Default Response
     * @throws ApiError
     */
    getNonce(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            status: string;
            nonce: string;
            walletAddress: string;
            chain: string;
        };
    }>;
    /**
     * Simulate a transaction
     * Simulate a transaction with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    simulateTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The contract address
         */
        toAddress: string;
        /**
         * The amount of native currency
         */
        value?: string;
        /**
         * The function to call on the contract
         */
        functionName?: string;
        args?: Array<string>;
        /**
         * Raw calldata
         */
        data?: string;
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Simulation Success
             */
            success: boolean;
        };
    }>;
}
