import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractEventsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all events
     * Get a list of all blockchain events for this contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param fromBlock
     * @param toBlock
     * @param order
     * @returns any Default Response
     * @throws ApiError
     */
    getAllEvents(chain: string, contractAddress: string, fromBlock?: (number | string), toBlock?: (number | string), order?: ('asc' | 'desc')): CancelablePromise<{
        result: Array<Record<string, any>>;
    }>;
    /**
     * Get events
     * Get a list of specific blockchain events emitted from this contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param requestBody Specify the from and to block numbers to get events for, defaults to all blocks
     * @returns any Default Response
     * @throws ApiError
     */
    getEvents(chain: string, contractAddress: string, requestBody: {
        eventName: string;
        fromBlock?: (number | string);
        toBlock?: (number | string);
        order?: ('asc' | 'desc');
        filters?: any;
    }): CancelablePromise<{
        result: Array<Record<string, any>>;
    }>;
    /**
     * Get subscribed contract event logs
     * Get event logs for a subscribed contract
     * @param fromBlock
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param toBlock
     * @param topics
     * @returns any Default Response
     * @throws ApiError
     */
    getContractEventLogs(fromBlock: number, chain: string, contractAddress: string, toBlock?: number, topics?: Array<string>): CancelablePromise<{
        result: {
            logs: Array<{
                chainId: number;
                contractAddress: string;
                blockNumber: number;
                transactionHash: string;
                topics: Array<string>;
                data: string;
                eventName?: string;
                decodedLog: any;
                timestamp: number;
                transactionIndex: number;
                logIndex: number;
            }>;
            status: string;
        };
    }>;
    /**
     * Get subscribed contract event logs
     * Get event logs for a subscribed contract
     * @param fromBlockTimestamp
     * @param contractAddresses
     * @param topics
     * @param toBlockTimestamp
     * @returns any Default Response
     * @throws ApiError
     */
    getEventLogs(fromBlockTimestamp: number, contractAddresses?: Array<string>, topics?: Array<string>, toBlockTimestamp?: number): CancelablePromise<{
        result: {
            logs: Array<{
                chainId: number;
                contractAddress: string;
                blockNumber: number;
                transactionHash: string;
                topics: Array<string>;
                data: string;
                eventName?: string;
                decodedLog: any;
                timestamp: number;
                transactionIndex: number;
                logIndex: number;
            }>;
            status: string;
        };
    }>;
    /**
     * Get contract paginated event logs for subscribed contract
     * Get contract paginated event logs for subscribed contract
     * @param cursor
     * @param pageSize
     * @param topics
     * @param contractAddresses
     * @returns any Default Response
     * @throws ApiError
     */
    pageEventLogs(cursor?: string, pageSize?: number, topics?: Array<string>, contractAddresses?: Array<string>): CancelablePromise<{
        result: {
            cursor?: string;
            logs: Array<{
                chainId: number;
                contractAddress: string;
                blockNumber: number;
                transactionHash: string;
                topics: Array<string>;
                data: string;
                eventName?: string;
                decodedLog: any;
                timestamp: number;
                transactionIndex: number;
                logIndex: number;
            }>;
            status: string;
        };
    }>;
}
