import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractRoyaltiesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get royalty details
     * Gets the royalty recipient and BPS (basis points) of the smart contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getDefaultRoyaltyInfo(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            /**
             * The royalty fee in BPS (basis points). 100 = 1%.
             */
            seller_fee_basis_points: number;
            /**
             * The wallet address that will receive the royalty fees.
             */
            fee_recipient: string;
        };
    }>;
    /**
     * Get token royalty details
     * Gets the royalty recipient and BPS (basis points) of a particular token in the contract.
     * @param tokenId
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getTokenRoyaltyInfo(tokenId: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            /**
             * The royalty fee in BPS (basis points). 100 = 1%.
             */
            seller_fee_basis_points: number;
            /**
             * The wallet address that will receive the royalty fees.
             */
            fee_recipient: string;
        };
    }>;
    /**
     * Set royalty details
     * Set the royalty recipient and fee for the smart contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    setDefaultRoyaltyInfo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The royalty fee in BPS (basis points). 100 = 1%.
         */
        seller_fee_basis_points: number;
        /**
         * The wallet address that will receive the royalty fees.
         */
        fee_recipient: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Set token royalty details
     * Set the royalty recipient and fee for a particular token in the contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    setTokenRoyaltyInfo(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The royalty fee in BPS (basis points). 100 = 1%.
         */
        seller_fee_basis_points: number;
        /**
         * The wallet address that will receive the royalty fees.
         */
        fee_recipient: string;
        /**
         * The token ID to set the royalty info for.
         */
        token_id: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
