import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class MarketplaceOffersService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all offers
     * Get all offers on this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param count Number of listings to fetch
     * @param offeror has offers from this Address
     * @param start Satrt from this index (pagination)
     * @param tokenContract Token contract address to show NFTs from
     * @param tokenId Only show NFTs with this ID
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(chain: string, contractAddress: string, count?: number, offeror?: string, start?: number, tokenContract?: string, tokenId?: string): CancelablePromise<{
        result: Array<{
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The id of the offer.
             */
            id: string;
            /**
             * The address of the creator of offer.
             */
            offerorAddress: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValue?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            /**
             * The total offer amount for the NFTs.
             */
            totalPrice: string;
            asset?: Record<string, any>;
            /**
             * The end time of the auction.
             */
            endTimeInSeconds?: number;
            status?: (number | 1 | 2 | 3 | 4 | 5);
        }>;
    }>;
    /**
     * Get all valid offers
     * Get all valid offers on this marketplace contract. Valid offers are offers that have not expired, been canceled, or been accepted.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param count Number of listings to fetch
     * @param offeror has offers from this Address
     * @param start Satrt from this index (pagination)
     * @param tokenContract Token contract address to show NFTs from
     * @param tokenId Only show NFTs with this ID
     * @returns any Default Response
     * @throws ApiError
     */
    getAllValid(chain: string, contractAddress: string, count?: number, offeror?: string, start?: number, tokenContract?: string, tokenId?: string): CancelablePromise<{
        result: Array<{
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The id of the offer.
             */
            id: string;
            /**
             * The address of the creator of offer.
             */
            offerorAddress: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValue?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            /**
             * The total offer amount for the NFTs.
             */
            totalPrice: string;
            asset?: Record<string, any>;
            /**
             * The end time of the auction.
             */
            endTimeInSeconds?: number;
            status?: (number | 1 | 2 | 3 | 4 | 5);
        }>;
    }>;
    /**
     * Get offer
     * Get details about an offer.
     * @param offerId The ID of the offer to get information about.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    getOffer(offerId: string, chain: string, contractAddress: string): CancelablePromise<{
        result: {
            /**
             * The address of the asset being listed.
             */
            assetContractAddress: string;
            /**
             * The ID of the token to list.
             */
            tokenId: string;
            /**
             * The address of the currency to accept for the listing.
             */
            currencyContractAddress?: string;
            /**
             * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
             */
            quantity?: string;
            /**
             * The id of the offer.
             */
            id: string;
            /**
             * The address of the creator of offer.
             */
            offerorAddress: string;
            /**
             * The `CurrencyValue` of the listing. Useful for displaying the price information.
             */
            currencyValue?: {
                name: string;
                symbol: string;
                decimals: number;
                value: string;
                displayValue: string;
            };
            /**
             * The total offer amount for the NFTs.
             */
            totalPrice: string;
            asset?: Record<string, any>;
            /**
             * The end time of the auction.
             */
            endTimeInSeconds?: number;
            status?: (number | 1 | 2 | 3 | 4 | 5);
        };
    }>;
    /**
     * Get total count
     * Get the total number of offers on this marketplace contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @returns any Default Response
     * @throws ApiError
     */
    getTotalCount(chain: string, contractAddress: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Make offer
     * Make an offer on a token. A valid listing is not required.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    makeOffer(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The address of the asset being listed.
         */
        assetContractAddress: string;
        /**
         * The ID of the token to list.
         */
        tokenId: string;
        /**
         * The address of the currency to accept for the listing.
         */
        currencyContractAddress?: string;
        /**
         * The quantity of tokens to include in the listing. NOTE: For ERC721s, this value should always be 1 (and will be forced internally regardless of what is passed here).
         */
        quantity?: string;
        /**
         * the price to offer in the currency specified
         */
        totalPrice: string;
        /**
         * Defaults to 10 years from now.
         */
        endTimestamp?: number;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Cancel offer
     * Cancel a valid offer made by the caller wallet.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    cancelOffer(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the offer to cancel. You can view all offers with getAll or getAllValid.
         */
        offerId: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Accept offer
     * Accept a valid offer.
     * @param chain Chain ID or name
     * @param contractAddress Contract Address on the Chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    acceptOffer(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The ID of the offer to accept. You can view all offers with getAll or getAllValid.
         */
        offerId: string;
    }, simulateTx?: boolean, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
